<?php
/*
  Plugin Name: Last Tweet
  Description: Echos the last published tweet(s) from twitter
  Version: 0.5
  Author: Frank Prins
  Author URI: http://www.frankprins.nl
*/

# get the correct id for this plugin
$thisfile=basename(__FILE__, ".php");
# add the plugin's language file
i18n_merge($thisfile) || i18n_merge($thisfile, 'en_US');

# register plugin into GetSimple
register_plugin(
	$thisfile, 
	i18n_r($thisfile.'/LASTTWEET_TITLE'), 	
	'0.6', 		
	'Frank Prins',
	'http://www.frankprins.nl/', 
	i18n_r($thisfile.'/LASTTWEET_DESC_SHORT'),
	'plugins',
	'cfg_tweet_show'  
);

# register the css, and queue it for use
register_style('lasttweet', $SITEURL.'plugins/'.$thisfile.'/lasttweet.css', GSVERSION, 'screen');
queue_style('lasttweet',GSBOTH);

# admin hooks 
add_action('plugins-sidebar','createSideMenu',array($thisfile, i18n_r($thisfile.'/LASTTWEET_MENUTITLE')));

# get config file path
$tweetcfg_file=GSDATAOTHERPATH .'LastTweetSettings.xml';

# call function to get the config data
get_config_data();

# get file, if exists, get data
function get_config_data() {
  global $tweetcfg_file, $accountname, $num_tweets;
  if (file_exists($tweetcfg_file)) {
	  $x = getXML($tweetcfg_file);
	  $accountname = $x->accountname;
	  $num_tweets = $x->numtweets;
  } else {
	  $accountname = '';
  }
}

# main function to call the last tweets
function show_tweets() {
  global $tweetcfg_file, $accountname, $num_tweets;
  # get config file
  get_config_data();
  // define the api url
  $url = 'https://api.twitter.com/1/statuses/user_timeline.json?screen_name='
         . $accountname . '&count=' . $num_tweets . '&include_entities=1&include_rts=1';
  $data = file_get_contents($url);
  // set up the json return
  $json = json_decode($data);

  if (!empty($json)) :
    foreach ($json as $tweet) :
      $datetime = niceTime(strtotime(str_replace("+0000", "", $tweet->created_at)));
      $tweet_text = $tweet->text;
      // check if any entites exist and if so, replace them with hyperlinkes
      if (!empty($tweet->entities->urls) || !empty($tweet->entities->hashtags) || !empty($tweet->entities->user_mentions)) {
        foreach ($tweet->entities->urls as $url) {
          $find = $url->url;
          $replace = '<a href="'.$find.'" target="_new">'.$find.'</a>';
          $tweet_text = str_replace($find,$replace,$tweet_text);
        }
        foreach ($tweet->entities->hashtags as $hashtag) {
          $find = '#'.$hashtag->text;
          $replace = '<a href="http://twitter.com/#!/search/%23'.$hashtag->text.'" target="_new">'.$find.'</a>';
          $tweet_text = str_replace($find,$replace,$tweet_text);
        }
        foreach ($tweet->entities->user_mentions as $user_mention) {
          $find = "@".$user_mention->screen_name;
          $replace = '<a href="http://twitter.com/'.$user_mention->screen_name.'" target="_new">'.$find.'</a>';
          $tweet_text = str_ireplace($find,$replace,$tweet_text);
        }
      }
    ?>
    <!-- write the tweet(s)   -->                            
    <div class="lasttweet">
      <span><?php echo $tweet_text; ?></span>
      <div class="datetime">
        <span><?php echo $datetime ?></span>
      </div>
    </div>                   
    <?php endforeach; ?>
  <?php endif; 
}

# call to get a nice date time string
function niceTime($time) {
  global $thisfile;
  $delta = time() - $time;
  if ($delta < 60) {
    return i18n_r($thisfile.'/DTM_LESS_ONE_MIN');
  } else if ($delta < 120) {
    return i18n_r($thisfile.'/DTM_ABOUT_ONE_MIN');
  } else if ($delta < (45 * 60)) {
    return floor($delta / 60).' '.i18n_r($thisfile.'/DTM_MINUTES');
  } else if ($delta < (90 * 60)) {
    return i18n_r($thisfile.'/DTM_ABOUT_ONE_HOUR');
  } else if ($delta < (24 * 60 * 60)) {
    return i18n_r($thisfile.'/DTM_ABOUT').' '. floor($delta / 3600).' '.i18n_r($thisfile.'/DTM_HOURS_AGO');
  } else if ($delta < (48 * 60 * 60)) {
    return i18n_r($thisfile.'/DTM_ONE_DAY_AGO');
  } else {
    return floor($delta / 86400) . ' ' . i18n_r($thisfile.'/DTM_DAYS_AGO');
  }
}

# configuration hook, to be used in admin section
function cfg_tweet_show() {
  	global $tweetcfg_file, $accountname, $num_tweets, $thisfile;
	         $success=null;$error=null;
  // submitted form, validate data and process
	if (isset($_POST['submit'])) {
		$accountname=null;
		$num_tweets=null;
		# check to see if the accountname provided are valid
		if (strlen($_POST['accountname']) > 3) {
			$accountname = $_POST['accountname'];
		} else {
			$error .= i18n_r($thisfile.'/TWITTER_ERROR').' ';
		}
		if ($_POST['num_tweets'] != '' && intval($_POST['num_tweets']) > 0 && 
        intval($_POST['num_tweets']) < 9) {
		  $num_tweets = intval($_POST['num_tweets']);
		} else {
		  $error .= i18n_r($thisfile.'/NUMTWEETS_ERROR').' ';
		}
		# if there are no errors, save data
		if (!$error) {
			$xml = @new SimpleXMLElement('<item></item>');
			$xml->addChild('accountname', $accountname);
			$xml->addChild('numtweets', $num_tweets);
			if (! $xml->asXML($tweetcfg_file)) {
				$error = i18n_r('CHMOD_ERROR');
			} else {
				$x = getXML($tweetcfg_file);
				$accountname = $x->accountname;
				$num_tweets = $x->numtweets;
				$success = i18n_r('SETTINGS_UPDATED');
			}
		}
	}

	?>
	<h3><?php i18n($thisfile.'/LASTTWEET_TITLE'); ?></h3>
	<p><?php i18n($thisfile.'/LASTTWEET_DESC_LONG'); ?></p>
	<?php 
	if($success) { 
		echo '<p style="color:#669933;"><b>'. $success .'</b></p>';
	} 
	if($error) { 
		echo '<p style="color:#cc0000;"><b>'. $error .'</b></p>';
	}
	?>
	
	<form method="post" action="<?php	echo $_SERVER ['REQUEST_URI']?>">
		<p><label for="twitter" ><?php i18n($thisfile.'/TWITTER_ACCOUNT'); ?></label>
    <input id="twitter" name="accountname" class="text" style="width: 100px;" value="<?php echo $accountname; ?>" type="text" /></p>
    <p><label for="num_tweets" ><?php i18n($thisfile.'/NUM_TWEETS'); ?></label>
    <input id="num_tweets" name="num_tweets" class="text" style="width: 100px;" value="<?php echo $num_tweets; ?>" type="text" /></p>
		<p><input type="submit" id="submit" class="submit" value="<?php i18n('BTN_SAVESETTINGS'); ?>" name="submit" /></p>
    <p>  
		 <h3>sample output:</h3>
		 <?php show_tweets(); ?>
		</p>
	</form>
	
	<?php
}